=============================
Kwant |release| documentation
=============================

.. toctree::
   :maxdepth: 2
   :numbered: 2

   pre/index
   tutorial/index
   reference/index

* :ref:`genindex`
